@@ -1,6 +1,6 @@
 __author__ = "Marco Berzborn"
 __email__ = 'marco.berzborn@akustik.rwth-aachen.de'
-__version__ = '0.3.2'
+__version__ = '0.4.2'
 
 from . import spherical
 from . import samplings
@@ -8,3 +8,15 @@ from . import plot
 from . import indexing
 from . import transforms
 from . import beamforming
+from . import interpolate
+
+
+__all__ = [
+    'spherical',
+    'samplings',
+    'plot',
+    'indexing',
+    'transforms',
+    'beamforming',
+    'interpolate'
+]
