@@ -88,16 +88,11 @@ def point_set_polar(dimension, N):
     else:
         # import ipdb; ipdb.set_trace()
         n_collars = np.size(n_regions) - 2
-        use_cache = dimension >= 2
-        if use_cache:
-            cache_size = np.floor(n_collars/2)
-            # cache =
 
         points_s = np.zeros((dimension, N))
         point_n = 2
         # points = np.zeros((dimension, N))
 
-        # TODO check what the offset is for
         offset = 0
 
         for collar_n in range(0, n_collars):
@@ -123,7 +118,7 @@ def point_set_polar(dimension, N):
 
             a_point = (a_top + a_bot)/2
 
-            point_l_n = np.arange(0, np.size(points_l), dtype=np.int)
+            point_l_n = np.arange(0, np.size(points_l), dtype=int)
             # points_l = points_l[np.newaxis]
 
             if dimension == 2:
@@ -133,7 +128,8 @@ def point_set_polar(dimension, N):
                 offset += circle_offset(n_in_collar, n_regions[2+collar_n])
                 offset -= np.floor(offset)
             else:
-                points_s[0:dimension-2, point_n+point_l_n-1] = points_l[:, point_l_n]
+                points_s[0:dimension-2, point_n+point_l_n-1] = \
+                    points_l[:, point_l_n]
 
             # import ipdb; ipdb.set_trace()
 
@@ -189,7 +185,7 @@ def caps(dimension, N):
     """
     if dimension == 1:
         s_cap = np.linspace(2*np.pi/N, 2*np.pi, N)
-        n_regions = np.ones(10, dtype=np.int)
+        n_regions = np.ones(10, dtype=int)
     elif N == 1:
         s_cap = np.pi
         n_regions = 1
@@ -299,7 +295,7 @@ def round_to_naturals(N, r_regions):
         The rounded integer number per collar.
     """
     r_regions = np.asarray(r_regions)
-    n_regions = np.zeros(r_regions.shape, dtype=np.int)
+    n_regions = np.zeros(r_regions.shape, dtype=int)
     discrepancy = 0
 
     for zone_n in range(0, np.size(r_regions)):
@@ -368,12 +364,12 @@ def num_collars(N, c_polar, a_ideal):
         The real number of collars.
 
     """
-    if np.int((N > 2) and (a_ideal > 0)):
+    if int((N > 2) and (a_ideal > 0)):
         n_collars = np.maximum(1, np.rint((np.pi - 2*c_polar) / a_ideal))
     else:
         n_collars = 0
 
-    return np.int(n_collars)
+    return int(n_collars)
 
 
 def circle_offset(n_top, n_bot, extra_twist=False):
