@@ -1,20 +1,13 @@
 """
 Tests for modal strength function
 """
-
-import sys
 from filehandling import read_matrix_from_mat
-
-sys.path.append('./')
-
-import pytest
 import spharpy.spherical as sh
 import numpy as np
-from spharpy import special
+
 
 def test_modal_strength_open():
     n_max = 5
-    n_sh = (n_max+1)**2
     n_bins = 128
     k = np.linspace(0.5, 15, n_bins)
     reference = read_matrix_from_mat('./tests/data/modal_strength_open.mat')
